@@ -21,6 +21,7 @@ from pytz import utc
 
 import beer_garden.api
 import beer_garden.api.entry_point
+import beer_garden.command_publishing_blocklist
 import beer_garden.config as config
 import beer_garden.db.api as db
 import beer_garden.events
@@ -247,6 +248,7 @@ class Application(StoppableThread):
 
         self.logger.debug("Publishing startup sync")
         beer_garden.garden.publish_garden()
+        beer_garden.command_publishing_blocklist.publish_command_publishing_blocklist()
 
         self.logger.debug("Starting plugin log config file monitors")
         if config.get("plugin.logging.config_file"):
@@ -254,9 +256,6 @@ class Application(StoppableThread):
         if config.get("plugin.local.logging.config_file"):
             self.plugin_local_log_config_observer.start()
 
-        self.logger.debug("Loading jobs from database")
-        self.scheduler.initialize_from_db()
-
         self.logger.info("All set! Let me know if you need anything else!")
 
     def _shutdown(self):
@@ -266,6 +265,7 @@ class Application(StoppableThread):
         )
 
         self.logger.debug("Publishing shutdown sync")
+        beer_garden.command_publishing_blocklist.publish_command_publishing_blocklist()
         beer_garden.garden.publish_garden(status="STOPPED")
 
         if self.scheduler.running:
@@ -338,7 +338,7 @@ class Application(StoppableThread):
             event_manager.register(
                 HttpParentUpdater(
                     easy_client=easy_client,
-                    block_list=config.get("parent.skip_events"),
+                    blocklist=config.get("parent.skip_events"),
                     reconnect_action=reconnect_action,
                 )
             )
