@@ -27,6 +27,7 @@ from brewtils.models import Event, Events, Garden, Operation, Request, System
 from stomp.exception import ConnectFailedException
 
 import beer_garden
+import beer_garden.command_publishing_blocklist
 import beer_garden.commands
 import beer_garden.config as config
 import beer_garden.db.api as db
@@ -38,6 +39,7 @@ import beer_garden.namespace
 import beer_garden.plugin
 import beer_garden.queues
 import beer_garden.requests
+import beer_garden.role
 import beer_garden.scheduler
 import beer_garden.systems
 import beer_garden.user
@@ -60,6 +62,8 @@ routable_operations = [
     "REQUEST_CREATE",
     "SYSTEM_DELETE",
     "GARDEN_SYNC",
+    "COMMAND_BLOCKLIST_ADD",
+    "COMMAND_BLOCKLIST_REMOVE",
     "USER_SYNC",
 ]
 
@@ -156,6 +160,8 @@ route_functions = {
     "RUNNER_RESCAN": beer_garden.local_plugins.manager.rescan,
     "PUBLISH_EVENT": beer_garden.events.publish,
     "USER_SYNC": beer_garden.user.user_sync,
+    "COMMAND_BLOCKLIST_ADD": beer_garden.command_publishing_blocklist.command_publishing_blocklist_add,
+    "COMMAND_BLOCKLIST_REMOVE": beer_garden.command_publishing_blocklist.command_publishing_blocklist_delete,
 }
 
 
@@ -565,13 +571,23 @@ def _target_from_type(operation: Operation) -> str:
         or "JOB" in operation.operation_type
         or "FILE" in operation.operation_type
         or operation.operation_type
-        in ("PLUGIN_LOG_RELOAD", "SYSTEM_CREATE", "SYSTEM_RESCAN")
+        in (
+            "PLUGIN_LOG_RELOAD",
+            "SYSTEM_CREATE",
+            "SYSTEM_RESCAN",
+        )
         or "PUBLISH_EVENT" in operation.operation_type
         or "RUNNER" in operation.operation_type
         or operation.operation_type in ("PLUGIN_LOG_RELOAD", "SYSTEM_CREATE")
     ):
         return config.get("garden.name")
 
+    if operation.operation_type in (
+        "COMMAND_BLOCKLIST_ADD",
+        "COMMAND_BLOCKLIST_REMOVE",
+    ):
+        return operation.target_garden_name
+
     # Otherwise, each operation needs to be "parsed"
     if operation.operation_type in ("SYSTEM_RELOAD", "SYSTEM_UPDATE"):
         return _system_id_lookup(operation.args[0])
